==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/BuiltInStandardEncoderPresetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.EncoderNamedPreset
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes a built-in preset for encoding the input video with the Standard Encoder.
 * @property configurations Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.BuiltInStandardEncoderPreset'.
 * @property presetName The built-in preset to be used for encoding videos.
 */
public data class BuiltInStandardEncoderPresetArgs(
    public val configurations: Output<PresetConfigurationsArgs>? = null,
    public val odataType: Output<String>,
    public val presetName: Output<Either<String, EncoderNamedPreset>>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs =
        com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs.builder()
            .configurations(configurations?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .presetName(
                presetName.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [BuiltInStandardEncoderPresetArgs].
 */
@PulumiTagMarker
public class BuiltInStandardEncoderPresetArgsBuilder internal constructor() {
    private var configurations: Output<PresetConfigurationsArgs>? = null

    private var odataType: Output<String>? = null

    private var presetName: Output<Either<String, EncoderNamedPreset>>? = null

    /**
     * @param value Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
     */
    @JvmName("weecenrxturqfktn")
    public suspend fun configurations(`value`: Output<PresetConfigurationsArgs>) {
        this.configurations = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.BuiltInStandardEncoderPreset'.
     */
    @JvmName("wvmaojutdavfreyj")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("txckcaeawsmqppow")
    public suspend fun presetName(`value`: Output<Either<String, EncoderNamedPreset>>) {
        this.presetName = value
    }

    /**
     * @param value Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
     */
    @JvmName("hlywekiynitdbvsg")
    public suspend fun configurations(`value`: PresetConfigurationsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurations = mapped
    }

    /**
     * @param argument Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
     */
    @JvmName("lxcbxusirqkydmip")
    public suspend fun configurations(argument: suspend PresetConfigurationsArgsBuilder.() -> Unit) {
        val toBeMapped = PresetConfigurationsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.configurations = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.BuiltInStandardEncoderPreset'.
     */
    @JvmName("optgrfmojwighkpi")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("swaomjdhpuhcycfq")
    public suspend fun presetName(`value`: Either<String, EncoderNamedPreset>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.presetName = mapped
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("ldxtgpkejyuhyopy")
    public fun presetName(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncoderNamedPreset>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.presetName = mapped
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("rmgvgvnrxvxjvkpv")
    public fun presetName(`value`: EncoderNamedPreset) {
        val toBeMapped = Either.ofRight<String, EncoderNamedPreset>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.presetName = mapped
    }

    internal fun build(): BuiltInStandardEncoderPresetArgs = BuiltInStandardEncoderPresetArgs(
        configurations = configurations,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        presetName = presetName ?: throw PulumiNullFieldException("presetName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/BuiltInStandardEncoderPresetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.EncoderNamedPreset
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes a built-in preset for encoding the input video with the Standard Encoder.
 * @property configurations Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.BuiltInStandardEncoderPreset'.
 * @property presetName The built-in preset to be used for encoding videos.
 */
public data class BuiltInStandardEncoderPresetArgs(
    public val configurations: Output<PresetConfigurationsArgs>? = null,
    public val odataType: Output<String>,
    public val presetName: Output<Either<String, EncoderNamedPreset>>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs =
        com.pulumi.azurenative.media.inputs.BuiltInStandardEncoderPresetArgs.builder()
            .configurations(configurations?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .presetName(
                presetName.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [BuiltInStandardEncoderPresetArgs].
 */
@PulumiTagMarker
public class BuiltInStandardEncoderPresetArgsBuilder internal constructor() {
    private var configurations: Output<PresetConfigurationsArgs>? = null

    private var odataType: Output<String>? = null

    private var presetName: Output<Either<String, EncoderNamedPreset>>? = null

    /**
     * @param value Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
     */
    @JvmName("eadljcuupvsxahfr")
    public suspend fun configurations(`value`: Output<PresetConfigurationsArgs>) {
        this.configurations = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.BuiltInStandardEncoderPreset'.
     */
    @JvmName("eawvtafbvmvrtali")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("iphvsqonmqneiini")
    public suspend fun presetName(`value`: Output<Either<String, EncoderNamedPreset>>) {
        this.presetName = value
    }

    /**
     * @param value Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
     */
    @JvmName("bymioebskwphxkct")
    public suspend fun configurations(`value`: PresetConfigurationsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurations = mapped
    }

    /**
     * @param argument Optional configuration settings for encoder. Configurations is only supported for ContentAwareEncoding and H265ContentAwareEncoding BuiltInStandardEncoderPreset.
     */
    @JvmName("hrcusahjouiqyvjf")
    public suspend fun configurations(argument: suspend PresetConfigurationsArgsBuilder.() -> Unit) {
        val toBeMapped = PresetConfigurationsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.configurations = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.BuiltInStandardEncoderPreset'.
     */
    @JvmName("lqqdvacabbjpdlfs")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("nufsydraockkiwyi")
    public suspend fun presetName(`value`: Either<String, EncoderNamedPreset>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.presetName = mapped
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("ycbaertbmcqoyhqk")
    public fun presetName(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncoderNamedPreset>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.presetName = mapped
    }

    /**
     * @param value The built-in preset to be used for encoding videos.
     */
    @JvmName("iihewfnpiftnuwjq")
    public fun presetName(`value`: EncoderNamedPreset) {
        val toBeMapped = Either.ofRight<String, EncoderNamedPreset>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.presetName = mapped
    }

    internal fun build(): BuiltInStandardEncoderPresetArgs = BuiltInStandardEncoderPresetArgs(
        configurations = configurations,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        presetName = presetName ?: throw PulumiNullFieldException("presetName"),
    )
}
